summaryrefslogtreecommitdiffstats
path: root/kmail/headerlistquicksearch.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headerlistquicksearch.h')
-rw-r--r--kmail/headerlistquicksearch.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/kmail/headerlistquicksearch.h b/kmail/headerlistquicksearch.h
index ddef0b40..df326a0a 100644
--- a/kmail/headerlistquicksearch.h
+++ b/kmail/headerlistquicksearch.h
@@ -18,20 +18,20 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
*/
-#ifndef KMAILHEADERLISQUICKSEARCH_H
-#define KMAILHEADERLISQUICKSEARCH_H
+#ifndef KMAILHEADERLISTQUICKSEARCH_H
+#define KMAILHEADERLISTQUICKSEARCH_H
-#include "kmmsgbase.h" // for KMMsgStatus
+#include "kmmsgbase.h" // for KMMsgtqStatus
#include "kmsearchpattern.h"
#include <klistviewsearchline.h>
#include <tqvaluevector.h>
@@ -45,8 +45,9 @@ namespace KMail {
class HeaderListQuickSearch : public KListViewSearchLine
{
Q_OBJECT
+ TQ_OBJECT
public:
- HeaderListQuickSearch( TQWidget *parent,
+ HeaderListQuickSearch( TQWidget *tqparent,
KListView *listView,
KActionCollection *actionCollection,
const char *name = 0 );
@@ -66,7 +67,7 @@ public:
/**
* Returns the currently selected status filter.
*/
- int currenStatus() const;
+ int currentqStatus() const;
public slots:
void reset();
@@ -76,23 +77,23 @@ signals:
protected:
/**
* checks whether @param item tqcontains the search string and has the status
* currently in mStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
private slots:
/**
* cache the status in mStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/
void sloStatusChanged( int index );
private:
/** Helper method for the filling of the status combo. */
- void inserStatus(KMail::StatusValueTypes which);
+ void insertqStatus(KMail::StatusValueTypes which);
TQComboBox *mStatusCombo;
- KMMsgStatus mStatus;
+ KMMsgtqStatus mtqStatus;
TQValueVector<TQString> statusList;
mutable TQString mCurrentSearchTerm;
};
@@ -76,23 +77,23 @@ signals:
protected:
/**
- * checks whether @param item tqcontains the search string and has the status
- * currently in mStatus
+ * checks whether @param item contains the search string and has the status
+ * currently in mtqStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
@@ -76,23 +77,23 @@ signals:
private slots:
/**
- * cache the status in mStatus so as to avoid having to do the comparatively
+ * cache the status in mtqStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/